LNT — LNT 0.4.1dev documentation

# LNT - LLVM Performance Tracking Software

LNT is LLVM's performance tracking software. This is the web page for the LNT software itself, the current online version of the server is available at http://llvm.org/perf/.

## Documentation

Contents for a complete overview Search page search the documentation | General Index all functions, classes, terms Module Index quick access to all documented modules

## Source

LNT is available in the LLVM GitHub repository: `git clone https://github.com/llvm/llvm-lnt.git`.